.. raw:: html

    <h1 align="center">djpro</h1>

.. -teaser-begin-

``djpro`` is the Python package that allows you to create a Django project
using a modular and scalable architecture options like API configuration,
DjangoAdminSite custom theme and Docker to optimize your development time.

.. -teaser-end-

.. -overview-

The idea of this package is to facilitate the creation of a Django project with a
modular and scalable architecture, facilitating and optimizing the development time.
Through CLI commands, you will be able to include configuration options such as:
``Django Rest Framework`` configuration for further API development. ``Unfold`` setup
and configuration for a customization of the Django Admin Site theme.
``Docker`` configuration from an early stage of development to facilitate
future deployment.

Using ``djpro`` you can stop creating the directories of your Django project
from scratch.

**Feature Support**

- Fast and easy API configuration
- Automatic customization of the Django Admin Site
- Easy implementation of the production environment configuration.

.. -project-information-

Project Information
===================

``djpro`` is released under the `MIT / X11 License <https://choosealicense.com/licenses/mit/>`__,
its documentation lives at `Read the Docs <https://djpro.readthedocs.io/en/latest/>`_,
the code on `GitHub <https://github.com/szew404/djpro>`_,
and the latest release on `PyPI <#>`_.

If you'd like to contribute to ``djpro`` you're most welcome!

.. -support-

Support
=======

Should you have any question, any remark, or if you find a bug, or if there is
something you can't do with the ``djpro``, please
`open an issue <https://github.com/szew404/djpro/issues>`_.